Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1034)

Unified Diff: chrome/browser/android/webapk/webapk_installer.h

Issue 2634173002: Fall back to legacy add to homescreen behavior on non-GMS device or GMS isn't availabe. (Closed)
Patch Set: Created 3 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/android/webapk/webapk_installer.h
diff --git a/chrome/browser/android/webapk/webapk_installer.h b/chrome/browser/android/webapk/webapk_installer.h
index a987e0450a561c93aa2d51b67e14ee129fb45eaf..57eac566eea970d93cddb7d99631ca2ec9c2ba92 100644
--- a/chrome/browser/android/webapk/webapk_installer.h
+++ b/chrome/browser/android/webapk/webapk_installer.h
@@ -124,10 +124,11 @@ class WebApkInstaller : public net::URLFetcherDelegate {
JNIEnv* env,
const base::android::ScopedJavaLocalRef<jstring>& java_file_path);
// Returns whether the Google Play install delegate is available.
// Note: it is possible that this delegate is null even when installing
// WebAPKs using Google Play is enabled.
- virtual bool HasGooglePlayWebApkInstallDelegate();
+ virtual bool CanUseGooglePlayInstallService();
// Called when the package name of the WebAPK is available and the install
// or update request is handled by Google Play.
@@ -124,10 +124,11 @@ class WebApkInstaller : public net::URLFetcherDelegate {
JNIEnv* env,
const base::android::ScopedJavaLocalRef<jstring>& java_file_path);
- // Returns whether the Google Play install delegate is available.
+ // Returns whether Google Play Service can be used and the install delegate is
+ // available.
// Note: it is possible that this delegate is null even when installing
// WebAPKs using Google Play is enabled.

Powered by Google App Engine
This is Rietveld 408576698